| dnnet-class | R Documentation |
An S4 class containing a deep neural network
normA list, containing the centers and s.d.'s of x matrix and y vector (if numeric)
weightA list of matrices, weight matrices in the fitted neural network
biasA list of vectors, bias vectors in the fitted neural network
lossThe minimum loss acheived from the validate set
loss.trajThe loss trajectory
labelIf the model is classification, a character vectors containing class labels
model.typeEither "Classification" or "Regression"
model.specOther possible information
dnnetInput-class
dnnet
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.