| permfit | R Documentation |
PermFIT: A permutation-based feature importance test.
permfit(
train,
validate = NULL,
k_fold = 5,
n_perm = 100,
pathway_list = list(),
method = c("ensemble_dnnet", "random_forest", "lasso", "linear", "svm", "dnnet",
"xgboost")[1],
shuffle = NULL,
...
)
train |
An dnnetInput or dnnetSurvInput object. |
validate |
A validation dataset is required when k_fold = 0. |
k_fold |
K-fold cross-fitting. If not, set k_fold to zero. |
n_perm |
Number of permutations repeated. |
pathway_list |
A list of pathways to be jointly tested. |
method |
Models, including |
shuffle |
If shuffle is null, the data will be shuffled for cross-fitting; if random shuffle is not desired, please provide a bector of numbers for cross-fitting indices |
... |
Additional parameters passed to each method. |
Returns a PrmFIT object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.