| ensemble_dnnet | R Documentation |
Fit a an ensemble model of DNNs
ensemble_dnnet(
object,
n.ensemble = 100,
esCtrl,
random.nbatch = FALSE,
random.nbatch.limit = NULL,
unbalance.trt = c("None", "Over", "Under", "Balance")[1],
bootstrap = TRUE,
prop.train = 1,
prop.keep = 1,
best.opti = TRUE,
min.keep = 10,
verbose = TRUE
)
object |
A |
n.ensemble |
The number of DNNs to be fit |
esCtrl |
A list of parameters to be passed to |
random.nbatch |
An indicator whether n.batch is randomly selected. |
random.nbatch.limit |
Minimum and maximum for randomly chosen n.batch. |
unbalance.trt |
Treatment for unbalanced labels. |
bootstrap |
Indicator for whether a bootstrap sampling is used. |
prop.train |
If bootstrap == FALSE, a training/validation cut for the data will be used (0, 1). |
prop.keep |
The proportion of DNNs to be kept in the ensemble. |
best.opti |
Whether to run the algorithm to keep the optimal subset of DNNs. |
min.keep |
Minimal number of DNNs to be kept. |
verbose |
Whether the progress to be printed. |
Returns a dnnetEnsemble object.
dnnetEnsemble-class
dnnetInput-class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.